-- $Id: Core.lua 7 2017-04-12 08:52:03Z arith $
-----------------------------------------------------------------------
-- Upvalued Lua API.
-----------------------------------------------------------------------
-- Functions
local _G = getfenv(0)
-- Libraries
-- ----------------------------------------------------------------------------
-- AddOn namespace.
-- ----------------------------------------------------------------------------
local FOLDER_NAME, private = ...

local LibStub = _G.LibStub
local L = LibStub("AceLocale-3.0"):GetLocale("AtlasLoot Button");

local addon = LibStub("AceAddon-3.0"):NewAddon("AtlasLoot Button");
addon.constants = private.constants;
addon.constants.addon_name = private.addon_name;
addon.Name = FOLDER_NAME;
_G.AtlasLoot_Button = addon;

local isInLockdown = false;
local db;

function addon:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("AtlasLootButtonDB", addon.constants.defaults, true)
	
	db = self.db.profile;

	self.db.RegisterCallback(self, "OnProfileChanged", "Refresh")
	self.db.RegisterCallback(self, "OnProfileCopied", "Refresh")
	self.db.RegisterCallback(self, "OnProfileReset", "Refresh")

	self:SetupOptions()
end

function addon:OnEnable()
end

function addon:Refresh()
	db = self.db.profile;
	if(db.show_button) then
		AtlasLootButton:Show();
	else
		AtlasLootButton:Hide();
	end
end

local function AtlasLoot_Button_Init()
	if(db.show_button) then
		AtlasLootButton:Show();
	else
		AtlasLootButton:Hide();
	end
end

function AtlasLoot_Button_OnLoad(self)
	-- Register events
	for key, value in pairs( addon.constants.events ) do
		self:RegisterEvent( value );
	end
	self:RegisterForDrag("LeftButton");
	self:RegisterForClicks("LeftButtonDown", "RightButtonDown");
end

function AtlasLoot_Button_OnEvent(self, event, ...)
	local arg1 = ...;
	if (event == "ADDON_LOADED" and arg1 == "AtlasLoot_Button") then
		AtlasLoot_Button_Init();
	end
	-- for combact lockdown
	if (event == "PLAYER_REGEN_DISABLED") then
		isInLockdown = true;
	elseif (event == "PLAYER_REGEN_ENABLED") then
		isInLockdown = false;
	end
end

function AtlasLoot_Button_OnMouseDown(self, buttonName)    
	if(AtlasLootButton:IsVisible()) then
		if (buttonName == "LeftButton") then
			-- Prevent activation when in combat
			if (db.disableDraggingInCombat and isInLockdown) then
				return;
			end
			GameTooltip:Hide();
			AtlasLootButton:StartMoving();
		elseif (buttonName == "RightButton") then
			if (AtlasLoot.GUI.frame:IsVisible()) then
				AtlasLoot.GUI.frame:Hide();
			else
				AtlasLoot.GUI.frame:Show();
			end
			GameTooltip_Hide();
		end
	end
end

function AtlasLoot_Button_OnMouseUp(self, buttonName)
	if(AtlasLootButton:IsVisible()) then
		AtlasLootButton:StopMovingOrSizing();
	end
end

function AtlasLoot_Button_OnEnter(self)
	if (db.show_tooltip) then
		GameTooltip:SetOwner(self, "ANCHOR_TOPRIGHT");
		GameTooltip:SetText(L["BUTTON_TEXT"], nil, nil, nil, nil, 1);
	end
end

function AtlasLoot_Button_OnLeave(self)
	GameTooltip:Hide();
end
